MODULE trclsm_lobster
   !!======================================================================
   !!                      ***  MODULE trclsm_lobster  ***
   !! TOP :   initialisation of some run parameters for LOBSTER bio-model
   !!======================================================================
   !! History :   2.0  !  2007-12  (C. Ethe, G. Madec) from trclsm.lobster1.h90
   !!----------------------------------------------------------------------
#if defined key_lobster
   !!----------------------------------------------------------------------
   !!   'key_lobster'   :                                 LOBSTER bio-model
   !!----------------------------------------------------------------------
   !! trc_lsm_lobster      : LOBSTER model namelist read
   !!----------------------------------------------------------------------
   USE oce_trc         ! Ocean variables
   USE par_trc         ! TOP parameters
   USE trc             ! TOP variables
   USE sms_lobster     ! sms trends

   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_lsm_lobster   ! called by trclsm.F90 module

   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Id: trclsm_lobster.F90 772 2007-12-17 11:59:33Z gm $ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_lsm_lobster
      !!----------------------------------------------------------------------
      !!                     ***  trc_lsm_lobster  ***  
      !!
      !! ** Purpose :   read LOBSTER namelist
      !!
      !! ** input   :   file 'namelist.trc.sms' containing the following
      !!             namelist: natbio, natopt, and natdbi ("key_trc_diabio")
      !!----------------------------------------------------------------------
      CHARACTER (len=32) :: clname
      !!
      NAMELIST/natbio/ apmin, azmin, anmin, admin,                       &
         &   redf, reddom, slopet, toptp, psinut, akno3, aknh4, rcchl,   &
         &   rgamma, toptgz, tmaxgz, rgz,                                &
         &   rppz, taus, aks, filmax, rpnaz, rdnaz, eggzoo, tauzn,       &
         &   tmmaxp, tmminp, tmmaxz, tmminz, anumin, afdmin, taudn,      &
         &   vsed, tmumax, aki, tmaxr, tminr, taunn, taudomn, xhr,       &
         &   sedlam, sedlostpoc,                                         &
         &   fphylab, fzoolab, fdetlab, fdbod
      NAMELIST/natopt/ xkg0, xkr0, xkgp, xkrp, xlg, xlr, rpig
#if defined key_trc_diabio
      INTEGER :: ji
      NAMELIST/natdbi/ctrbio,ctrbil,ctrbiu,nwritebio
#endif
      !!----------------------------------------------------------------------

      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) ' trc_lsm_lobster : read LOBSTER namelists'
      IF(lwp) WRITE(numout,*) ' ~~~~~~~~~~~~~~~'

      !                               ! Open the namelist file
      !                               ! ----------------------
      clname ='namelist_lobster'
      CALL ctlopn( numnat, clname, 'OLD', 'FORMATTED', 'SEQUENTIAL',   &
         &           1, numout, .FALSE., 1 )

      !                               ! natbio : biological parameters
      !                               ! ------------------------------
      apmin = 0.                           ! default values
      azmin = 0.
      anmin = 0.
      admin = 0.
      redf  = 0.
      reddom = 0.
      slopet = 0.
      toptp = 0.
      psinut = 0.
      akno3  = 0.
      aknh4 = 0.
      rcchl = 0.
      rgamma= 0.
      toptgz= 0.
      tmaxgz= 0.
      rgz   = 0.
      rppz  = 0.
      taus  = 0.
      aks   = 0.
      filmax= 0.
      rpnaz = 0.
      rdnaz = 0.
      eggzoo= 0.
      tauzn = 0.
      tmmaxp= 0.
      tmminp= 0.
      tmmaxz= 0.
      tmminz= 0.
      anumin= 0.
      afdmin= 0.
      taudn = 0.
      vsed  = 0.
      tmumax= 0.
      aki   = 0.
      tmaxr   = 1./(     4.*rday)*0.
      tminr   = 1./(24.*30.*rday)*0.
      xhr=0.
      sedlam=0.
      sedlostpoc=0.
      taudomn = 0.
      taunn = 0.
      fphylab = 0.
      fzoolab = 0.
      fdetlab = 0.
      fdbod = 0.

      REWIND( numnat )                     ! read natbio
      READ  ( numnat, natbio )

      IF(lwp) THEN
          WRITE(numout,*) ' Namelist natbio'
          WRITE(numout,*) '    minimum phytoplancton concentration                  apmin     =', apmin
          WRITE(numout,*) '    minimum zooplancton   concentration                  azmin     =', azmin
          WRITE(numout,*) '    minimum nutrients     concentration                  anmin     =', anmin
          WRITE(numout,*) '    minimum detritus      concentration                  admin     =', admin
          WRITE(numout,*) '    redfield ratio  c:n                                  redf      =', redf
          WRITE(numout,*) '    van t hoff coefficient                               slopet    =', slopet
          WRITE(numout,*) '    optimal photosynthesis temperature                   toptp     =', toptp
          WRITE(numout,*) '    inhibition of no3 uptake by nh4                      psinut    =', psinut
          WRITE(numout,*) '    half-saturation nutrient for no3 uptake              akno3     =', akno3
          WRITE(numout,*) '    half-saturation nutrient for nh4 uptake              aknh4     =', aknh4
          WRITE(numout,*) '    carbone/chlorophyl ratio                             rcchl     =', rcchl
          WRITE(numout,*) '    phytoplankton exudation fraction                     rgamma    =', rgamma
          WRITE(numout,*) '    optimal temperature for zoo growth                   toptgz    =', toptgz
          WRITE(numout,*) '    maximal temperature for zoo growth                   tmaxgz    =', tmaxgz
          WRITE(numout,*) '    widtht of zoo temperature FUNCTION                   rgz       =', rgz
          WRITE(numout,*) '    zoo preference for phyto                             rppz      =', rppz
          WRITE(numout,*) '    maximal zoo grazing rate                             taus      =', 86400 * taus, ' d'
          WRITE(numout,*) '    half saturation constant for zoo food                aks       =', aks
          WRITE(numout,*) '    maximal mass clearance rate for zoo                  filmax    =', filmax
          WRITE(numout,*) '    non-assimilated phyto by zoo                         rpnaz     =', rpnaz
          WRITE(numout,*) '    non-assimilated detritus by zoo                      rdnaz     =', rdnaz
          WRITE(numout,*) '    minimum  for zoo concentration                       eggzoo    =', eggzoo
          WRITE(numout,*) '    zoo specific excretion rate                          tauzn     =', 86400 * tauzn
          WRITE(numout,*) '    maximal phyto mortality rate                         tmmaxp    =', 86400 * tmmaxp
          WRITE(numout,*) '    minimal phyto mortality rate                         tmminp    =', 86400 * tmminp
          WRITE(numout,*) '    maximal zoo mortality rate                           tmmaxz    =', 86400 * tmmaxz
          WRITE(numout,*) '    minimal zoo mortality rate                           tmminz    =', 86400 * tmminz
          WRITE(numout,*) '    nutrient threshold for phyto mort                    anumin    =', anumin
          WRITE(numout,*) '    food threshold for zoo mort                          afdmin    =', afdmin
          WRITE(numout,*) '    detrital breakdown rate                              taudn     =', 86400 * taudn , ' d'
          WRITE(numout,*) '    detritus sedimentation speed                         vsed      =', 86400 * vsed  , ' d'
          WRITE(numout,*) '    phyto max growth rate                                tmumax    =', 86400 * tmumax, ' d'
          WRITE(numout,*) '    light hlaf saturation constant                       aki       =', aki
          WRITE(numout,*) '    maximum damping for d z or p                         tmaxr     =', tmaxr
          WRITE(numout,*) '    damping-remineralisation rate                        tminr     =', tminr
          WRITE(numout,*) '    nitrification rate                                   taunn     =', taunn
          WRITE(numout,*) '    dom remineralisation rate                            taudomn   =', taudomn
          WRITE(numout,*) '    coeff for martin''s remineralistion                  xhr       =', xhr
          WRITE(numout,*) '    time coeff of POC in sediments                       sedlam    =', sedlam
          WRITE(numout,*) '    Sediment geol loss for POC                           sedlostpoc=', sedlostpoc
          WRITE(numout,*) '    NH4 fraction of phytoplankton exsudation             fphylab   =', fphylab
          WRITE(numout,*) '    NH4 fraction of zooplankton excretion                fzoolab   =', fzoolab
          WRITE(numout,*) '    NH4 fraction of detritus dissolution                 fdetlab   =', fdetlab
          WRITE(numout,*) '    Zooplankton mortality fraction that goes to detritus fdbod     =', fdbod
      ENDIF

      !                               ! natopt : optical parameters
      !                               ! ---------------------------
      xkg0  = 0.                           ! default values
      xkr0  = 0.
      xkgp  = 0.
      xkrp  = 0.
      xlg   = 0.
      xlr   = 0.
      rpig  = 0.

      REWIND( numnat )                     ! read natopt
      READ  ( numnat, natopt )       

      IF(lwp) THEN                         ! control print
         WRITE(numout,*)
         WRITE(numout,*) ' Namelist natopt'
         WRITE(numout,*) '    green   water absorption coeff                       xkg0  = ', xkg0
         WRITE(numout,*) '    red water absorption coeff                           xkr0  = ', xkr0
         WRITE(numout,*) '    pigment red absorption coeff                         xkrp  = ', xkrp
         WRITE(numout,*) '    pigment green absorption coeff                       xkgp  = ', xkgp
         WRITE(numout,*) '    green chl exposant                                   xlg   = ', xlg
         WRITE(numout,*) '    red   chl exposant                                   xlr   = ', xlr
         WRITE(numout,*) '    chla/chla+phea ratio                                 rpig  = ', rpig
      ENDIF

#if defined key_trc_diabio

      !                               ! natdbi : bio diagnostics
      !                               ! ------------------------
      nwritebio = 10                     ! default values
      DO ji = 1, jpdiabio
         IF(     ji <  10 ) THEN   ;   WRITE (ctrbio(ji),'("BIO_",I1)') ji      ! short name
         ELSEIF (ji < 100 ) THEN   ;   WRITE (ctrbio(ji),'("BIO_",I2)') ji   
         ELSE                      ;   WRITE (ctrbio(ji),'("BIO_",I3)') ji
         ENDIF
         WRITE(ctrbil(ji),'("BIOLOGICAL TREND NUMBER ",I2)') ji                 ! long name
         ctrbiu(ji) = 'mmoleN/m3/s '                                            ! units
      END DO

      REWIND( numnat )                     ! read natdbi
      READ  ( numnat, natdbi )  

      IF(lwp) THEN
         WRITE(numout,*)
         WRITE(numout,*) ' Namelist natdbi'
         WRITE(numout,*) '    frequency of outputs for biological outputs  nwritebio = ', nwritebio
         DO ji = 1, jpdiabio
            WRITE(numout,*) '     name of biological trend No :',ji,' : ',ctrbio(ji), ctrbil(ji), ' in ', ctrbiu(ji)
         END DO
      END IF
#endif
      !
   END SUBROUTINE trc_lsm_lobster
   
#else
   !!----------------------------------------------------------------------
   !!  Dummy module :                                            No LOBSTER
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_lsm_lobster                      ! Empty routine
   END  SUBROUTINE  trc_lsm_lobster
#endif  

   !!======================================================================
END MODULE trclsm_lobster
