MODULE trclsm_pisces
   !!======================================================================
   !!                      ***  MODULE trclsm_lobster  ***
   !! TOP :   initialisation of some run parameters for PISCES bio-model
   !!======================================================================
   !! History :    -   !  1999-10 (M.A. Foujols, M. Levy) original code
   !!              -   !  2000-01 (L. Bopp) hamocc3, p3zd
   !!             1.0  !  2003-08 (C. Ethe)  module F90
   !!             2.0  !  2007-12  (C. Ethe, G. Madec) from trclsm.pisces.h90
   !!----------------------------------------------------------------------
#if defined key_pisces
   !!----------------------------------------------------------------------
   !!   'key_pisces'   :                                   PISCES bio-model
   !!----------------------------------------------------------------------
   !! trc_lsm_pisces       : PISCES model namelist read
   !!----------------------------------------------------------------------
   USE oce_trc         ! Ocean variables
   USE par_trc         ! TOP parameters
   USE trc             ! TOP variables
   USE sms_pisces      ! sms trends


   IMPLICIT NONE
   PRIVATE

   PUBLIC   trc_lsm_pisces   ! called by trclsm.F90 module


   !!----------------------------------------------------------------------
   !! NEMO/TOP 2.0 , LOCEAN-IPSL (2007) 
   !! $Id: trclsm_pisces.F90 773 2007-12-17 16:55:32Z gm $ 
   !! Software governed by the CeCILL licence (modipsl/doc/NEMO_CeCILL.txt)
   !!----------------------------------------------------------------------

CONTAINS

   SUBROUTINE trc_lsm_pisces
      !!----------------------------------------------------------------------
      !!                     ***  trc_lsm_pisces  ***  
      !!
      !! ** Purpose :   read PISCES namelist
      !!
      !! ** input   :   file 'namelist.trc.sms' containing the following
      !!             namelist: natext, natbio, natsms
      !!                       natkriest ("key_kriest")
      !!----------------------------------------------------------------------
      CHARACTER (len=32) ::   clname
      !!
      NAMELIST/natbio/ part, nrdttrc, wsbio, xkmort, ferat3, wsbio2

#if defined key_kriest
      NAMELIST/natkrpar/xkr_eta, xkr_zeta, xkr_mass_min, xkr_mass_max
#endif
      !!----------------------------------------------------------------------

      IF(lwp) WRITE(numout,*)
      IF(lwp) WRITE(numout,*) ' trc_lsm_pisces : read PISCES namelists'
      IF(lwp) WRITE(numout,*) ' ~~~~~~~~~~~~~~'


      !                               ! Open the namelist file
      !                               ! ----------------------
      clname ='namelist_pisces'
      CALL ctlopn( numnat, clname, 'OLD', 'FORMATTED', 'SEQUENTIAL',   &
         &           1, numout, .FALSE., 1 )

      !                               ! natbio : biological parameters
      !                               ! ------------------------------
      REWIND( numnat )                     ! read natbio
      READ  ( numnat, natbio )

      IF(lwp) THEN                         ! control print
         WRITE(numout,*) ' Namelist : natbio'
         WRITE(numout,*) '    part of calcite not dissolved in guts     part      =', part
         WRITE(numout,*) '    frequence pour la biologie                nrdttrc   =', nrdttrc
         WRITE(numout,*) '    POC sinking speed                         wsbio     =', wsbio
         WRITE(numout,*) '    half saturation constant for mortality    xkmort    =', xkmort
         WRITE(numout,*) '    Fe/C in zooplankton                       ferat3    =', ferat3
         WRITE(numout,*) '    Big particles sinking speed               wsbio2    =', wsbio2
      ENDIF

#if defined key_kriest

      !                               ! natkrpar : kriest parameters
      !                               ! -----------------------------
      xkr_eta      = 0.62        
      xkr_zeta     = 1.62        
      xkr_mass_min = 0.0002     
      xkr_mass_max = 1.      

      REWIND( numnat )                     ! read natkriest
      READ  ( numnat, natkrpar )

      IF(lwp) THEN
         WRITE(numout,*)
         WRITE(numout,*) ' Namelist : natkrpar'
         WRITE(numout,*) '    Sinking  exponent                        xkr_eta      = ', xkr_eta
         WRITE(numout,*) '    N content exponent                       xkr_zeta     = ', xkr_zeta
         WRITE(numout,*) '    Minimum mass for Aggregates              xkr_mass_min = ', xkr_mass_min
         WRITE(numout,*) '    Maximum mass for Aggregates              xkr_mass_max = ', xkr_mass_max
         WRITE(numout,*)
     ENDIF


     ! Computation of some variables
     xkr_massp = 5.7E-6 * 7.6 * xkr_mass_min**xkr_zeta

#endif
      !
   END SUBROUTINE trc_lsm_pisces

#else
   !!----------------------------------------------------------------------
   !!  Dummy module :                                   No PISCES bio-model
   !!----------------------------------------------------------------------
CONTAINS
   SUBROUTINE trc_lsm_pisces                      ! Empty routine
   END  SUBROUTINE  trc_lsm_pisces
#endif  

   !!======================================================================
END MODULE trclsm_pisces
